from setuptools import setup

setup(name='gauscalc',
      version='1.0',
      description='Calculate and Plot Gaussian and Binomail distributions',
      packages=['gauscalc'],
      author = 'Abdullah Alam Tapadar',
      author_email = 'abdullah.alam.tapadar2000@gmail.com',
      zip_safe=False)
